@@ -71,7 +71,7 @@ export namespace CliContext {
   export const CLI_ERROR_LOG = 'cli-error-log'
   export const CLI_COMMAND_LOGS_DIR = 'cli-logs-log'
   export const CLI_IS_DEV_VERSION = 'cli-dev-version'
-  export const CLI_IS_CHECTL = 'cli-is-chectl'
+  export const CLI_IS_CHECTL = 'cli-is-dsc'
   export const CLI_CHE_OPERATOR_RESOURCES_DIR = 'cli-che-operator-resources-dir'
   export const CLI_DEV_WORKSPACE_OPERATOR_RESOURCES_DIR = 'cli-dev-workspace-operator-resources-dir'
   export const CLI_COMMAND_POST_OUTPUT_MESSAGES = 'cli-messages'
@@ -130,7 +130,7 @@ export namespace OperatorImageUpgradeContext {
 }
 
 /**
- * chectl command context.
+ * dsc command context.
  * Can be requested from any location with `ChectlContext#get`
  */
 export namespace CheCtlContext {
@@ -148,7 +148,7 @@ export namespace CheCtlContext {
     ctx[CliContext.CLI_CACHE_DIR] = command.config.cacheDir
     ctx[CliContext.CLI_ERROR_LOG] = command.config.errlog
     ctx[CliContext.CLI_COMMAND_ID] = command.id
-    ctx[CliContext.CLI_COMMAND_LOGS_DIR] = path.resolve(flags[LOG_DIRECTORY_FLAG] ? flags[LOG_DIRECTORY_FLAG] : path.resolve(os.tmpdir(), 'chectl-logs', Date.now().toString()))
+    ctx[CliContext.CLI_COMMAND_LOGS_DIR] = path.resolve(flags[LOG_DIRECTORY_FLAG] ? flags[LOG_DIRECTORY_FLAG] : path.resolve(os.tmpdir(), 'dsc-logs', Date.now().toString()))
     ctx[CliContext.CLI_COMMAND_POST_OUTPUT_MESSAGES] = [] as string[]
 
     if (flags[TEMPLATES_FLAG]) {
